@@ -19,27 +19,39 @@ get_feed_args(struct menu_state *ctx, size_t index)
 	static struct format_arg feed_fmt[] = {
 		{L'i',  L'd',  {.i = 0   }},
 		{L'u',  L'd',  {.i = 0   }},
+		{L'n',  L'd',  {.i = 0   }},
 		{L'l',  L's',  {.s = NULL}},
 		{L't',  L's',  {.s = NULL}},
 		{L'\0', L'\0', {.i = 0   }}, // terminator
 	};
 	feed_fmt[0].value.i = index + 1;
 	feed_fmt[1].value.i = ctx->feeds[index]->unread_count;
-	feed_fmt[2].value.s = ctx->feeds[index]->url->ptr;
-	feed_fmt[3].value.s = STRING_IS_EMPTY(ctx->feeds[index]->name) ? ctx->feeds[index]->url->ptr : ctx->feeds[index]->name->ptr;
+	feed_fmt[2].value.i = ctx->feeds[index]->items_count;
+	feed_fmt[3].value.s = ctx->feeds[index]->url->ptr;
+	feed_fmt[4].value.s = STRING_IS_EMPTY(ctx->feeds[index]->name) ? ctx->feeds[index]->url->ptr : ctx->feeds[index]->name->ptr;
 	return feed_fmt;
 }
 
 static struct config_color
-paint_feed(struct menu_state *ctx, size_t index)
+paint_feed(struct menu_state *ctx, size_t index, bool is_selected)
 {
+	struct config_context **cfg = &ctx->feeds[index]->cfg;
+	struct config_color color;
 	if (ctx->feeds[index]->errors->len > 0 && !get_cfg_bool(&ctx->feeds[index]->cfg, CFG_SUPPRESS_ERRORS)) {
-		return get_cfg_color(&ctx->feeds[index]->cfg, CFG_COLOR_LIST_FEED_FAILED);
+		color = get_cfg_color(cfg, CFG_COLOR_LIST_FEED_FAILED);
 	} else if (ctx->feeds[index]->unread_count > 0) {
-		return get_cfg_color(&ctx->feeds[index]->cfg, CFG_COLOR_LIST_FEED_UNREAD);
+		color = get_cfg_color(cfg, CFG_COLOR_LIST_FEED_UNREAD);
 	} else {
-		return get_cfg_color(&ctx->feeds[index]->cfg, CFG_COLOR_LIST_FEED);
+		color = get_cfg_color(cfg, CFG_COLOR_LIST_FEED);
 	}
+	if (is_selected) {
+		if (is_cfg_color_set(cfg, CFG_COLOR_LIST_FEED_SELECTED)) {
+			color = get_cfg_color(cfg, CFG_COLOR_LIST_FEED_SELECTED);
+		} else {
+			color.attributes |= TB_REVERSE;
+		}
+	}
+	return color;
 }
 
 static bool
@@ -155,7 +167,7 @@ feeds_menu_loop(struct menu_state *m)
 			case INPUT_TOGGLE_EXPLORE_MODE:
 				return setup_menu(&items_menu_loop, NULL, m->feeds, m->feeds_count, MENU_IS_EXPLORE, NULL);
 			case INPUT_APPLY_SEARCH_MODE_FILTER:
-				return setup_menu(&items_menu_loop, NULL, m->feeds, m->feeds_count, MENU_IS_EXPLORE, NULL);
+				return setup_menu(&items_menu_loop, NULL, m->feeds, m->feeds_count, MENU_IS_SEARCH | MENU_IS_EXPLORE, NULL);
 			case INPUT_NAVIGATE_BACK:
 				if (get_menu_depth() < 2) break;
 				// fall through
