@@ -115,7 +115,7 @@ generate_render_blocks_based_on_item_data(struct render_blocks_list *blocks, con
 					struct string *value = NULL;
 					pthread_mutex_lock(&interface_lock);
 					switch (specifier) {
-						case 'f': value = block_str(STRING_IS_EMPTY(item->feed[0]->name) ? item->feed[0]->link : item->feed[0]->name); break;
+						case 'f': value = block_str(STRING_IS_EMPTY(item->feed[0]->name) ? item->feed[0]->url : item->feed[0]->name); break;
 						case 't': value = block_str(item->title); break;
 						case 'l': value = block_str(item->url);   break;
 						case 'd': value = block_date(item);       break;
