@@ -13,7 +13,7 @@
 #include "termbox2.h"
 
 #ifndef NEWSRAFT_VERSION
-#define NEWSRAFT_VERSION "0.34"
+#define NEWSRAFT_VERSION "0.35"
 #endif
 
 #define ISWHITESPACE(A) (((A)==' ')||((A)=='\n')||((A)=='\t')||((A)=='\v')||((A)=='\f')||((A)=='\r'))
@@ -162,6 +162,7 @@ struct feed_entry {
 	int64_t unread_count;
 	int64_t items_count;
 	int64_t update_date; // date of last feed update attempt
+	int64_t section_index;
 	struct config_context *cfg;
 	struct input_binding *binds;
 	struct string *errors;
@@ -338,6 +339,7 @@ bool print_unread_items_count(void);
 void process_auto_updating_feeds(void);
 void mark_feeds_read(struct feed_entry **feeds, size_t feeds_count, bool status);
 struct feed_entry **get_all_feeds(size_t *feeds_count);
+char *get_section_name(size_t section_index);
 
 // See "feeds-parse.c" file for implementation.
 bool parse_feeds_file(void);
@@ -369,7 +371,7 @@ void pager_menu_writer(size_t index, WINDOW *w);
 bool start_pager_menu(struct config_context **new_ctx, struct render_blocks_list *new_blocks);
 bool refresh_pager_menu(void);
 
-// See "format.c" file for implementation.
+// See "wstring-format.c" file for implementation.
 void do_format(struct wstring *dest, const wchar_t *fmt, const struct format_arg *args);
 
 // See "sorting.c" file for implementation.
