@@ -10,7 +10,7 @@ test1(const char *content, size_t size)
 	}
 
 	if (strcmp(data.feed.title->ptr, "My Example Feed") != 0) return 1;
-	if (strcmp(data.feed.url->ptr, "https://example.org/") != 0) return 1;
+	if (strcmp(data.feed.link->ptr, "https://example.org/") != 0) return 1;
 
 	size_t items_count = 0;
 	for (struct getfeed_item *i = data.feed.item; i != NULL; i = i->next) {
@@ -23,8 +23,8 @@ test1(const char *content, size_t size)
 
 	if (strcmp(item1->guid->ptr, "1") != 0) return 1;
 	if (strcmp(item2->guid->ptr, "2") != 0) return 1;
-	if (strcmp(item1->url->ptr, "https://example.org/initial-post") != 0) return 1;
-	if (strcmp(item2->url->ptr, "https://example.org/second-item")  != 0) return 1;
+	if (strcmp(item1->link->ptr, "https://example.org/initial-post") != 0) return 1;
+	if (strcmp(item2->link->ptr, "https://example.org/second-item")  != 0) return 1;
 	if (strcmp(item1->content->ptr, "\x1F^\x1Ftype=text/html\x1Ftext=<p>Hello, world!</p>") != 0) return 1;
 	if (strcmp(item2->content->ptr, "\x1F^\x1Ftext=This is a second item.") != 0) return 1;
 
@@ -40,7 +40,7 @@ test2(const char *content, size_t size)
 	}
 
 	if (strcmp(data.feed.title->ptr, "The Record") != 0) return 1;
-	if (strcmp(data.feed.url->ptr, "http://therecord.co/") != 0) return 1;
+	if (strcmp(data.feed.link->ptr, "http://therecord.co/") != 0) return 1;
 
 	size_t items_count = 0;
 	for (struct getfeed_item *i = data.feed.item; i != NULL; i = i->next) {
@@ -52,7 +52,7 @@ test2(const char *content, size_t size)
 
 	if (strcmp(item->guid->ptr, "http://therecord.co/chris-parrish") != 0) return 1;
 	if (strcmp(item->title->ptr, "Special #1 - Chris Parrish") != 0) return 1;
-	if (strcmp(item->url->ptr, "http://therecord.co/chris-parrish") != 0) return 1;
+	if (strcmp(item->link->ptr, "http://therecord.co/chris-parrish") != 0) return 1;
 	if (item->publication_date != 1399669440LL) return 1;
 
 	size_t texts_count = 0;
@@ -83,7 +83,7 @@ test3(const char *content, size_t size)
 	}
 
 	if (strcmp(data.feed.title->ptr, "Brent Simmons’s Microblog") != 0) return 1;
-	if (strcmp(data.feed.url->ptr, "https://example.org/") != 0) return 1;
+	if (strcmp(data.feed.link->ptr, "https://example.org/") != 0) return 1;
 	if (strcmp(data.feed.persons->ptr, "\x1F^\x1Ftype=author\x1Fname=Brent Simmons\x1Furl=http://example.org/") != 0) return 1;
 
 	size_t items_count = 0;
@@ -95,7 +95,7 @@ test3(const char *content, size_t size)
 	struct getfeed_item *item = data.feed.item;
 
 	if (strcmp(item->guid->ptr, "2347259") != 0) return 1;
-	if (strcmp(item->url->ptr, "https://example.org/2347259") != 0) return 1;
+	if (strcmp(item->link->ptr, "https://example.org/2347259") != 0) return 1;
 	if (strcmp(item->content->ptr, "\x1F^\x1Ftext=Cats are neat. \n\nhttps://example.org/cats") != 0) return 1;
 	if (item->publication_date != 1455052920LL) return 1;
 
